#
# spec file for package redland-bindings
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with perl
%define redland_version 1.0.17

Name:           redland-bindings
Version:        1.0.17.1
Release:        6.3
Summary:        Bindings for the Redland Libraries (RDF)
License:        LGPL-2.1+ and Apache-2.0
Group:          System/Libraries
Url:            http://www.librdf.org
Source0:        http://download.librdf.org/source/%{name}-%{version}.tar.gz
BuildRequires:  libredland-devel = %{redland_version}
BuildRequires:  perl-base
BuildRequires:  php5-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  ruby-devel
BuildRequires:  swig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Bindings for the Redland RDF Libraries

%prep

%setup -q

%build
export PYTHON_LIB="%{python_sitearch}"
%configure \
%if 0%{?suse_version} >= 1220
    --with-ruby --with-ruby-arch-install-dir-variable=vendorarchdir --with-ruby-install-dir=%{rb_vendorarchdir} \
%else
    --with-ruby \
%endif
%if %{with perl}
    --with-perl \
%endif
    --with-python \
    --with-php

make %{?_smp_mflags}

%install
%make_install
%if %{with perl}
find %{buildroot}%{perl_sitearch}/ -name '.packlist' -delete
find %{buildroot}%{perl_sitearch}/ -empty -delete
%endif

%if %{with perl}

%package -n perl-redland
Summary:        Perl bindings for programs that use Redland
Group:          Development/Languages/Perl
%requires_eq libredland0
Requires:       perl-base = %{perl_version}

%description -n perl-redland
Redland librdf Language bindings provide high-level interfaces for
RDF (Resource Description Framework) implemented on top of the
Redland librdf library which provides an object-based RDF API,
supports for syntaxes and triple stores.
Perl language bindings for the Redland RDF library.

%files -n perl-redland
%defattr(-, root, root)
%dir %{perl_sitearch}/RDF
%dir %{perl_sitearch}/auto
%dir %{perl_sitearch}/auto/RDF
%dir %{perl_sitearch}/auto/RDF/Redland
%dir %{perl_sitearch}/auto/RDF/Redland/CORE
%{perl_archlib}/perllocal.pod
%{perl_sitearch}/RDF/Redland.pm
%{perl_sitearch}/RDF/Redland/*.pm
%{perl_sitearch}/RDF/Redland/
%{perl_sitearch}/auto/RDF/Redland/CORE/CORE.so
%{_mandir}/man3/RDF::Redland.3pm.gz
%{_mandir}/man3/RDF::Redland::BlankNode.3pm.gz
%{_mandir}/man3/RDF::Redland::Iterator.3pm.gz
%{_mandir}/man3/RDF::Redland::LiteralNode.3pm.gz
%{_mandir}/man3/RDF::Redland::Model.3pm.gz
%{_mandir}/man3/RDF::Redland::Node.3pm.gz
%{_mandir}/man3/RDF::Redland::Parser.3pm.gz
%{_mandir}/man3/RDF::Redland::Query.3pm.gz
%{_mandir}/man3/RDF::Redland::QueryResults.3pm.gz
%{_mandir}/man3/RDF::Redland::RSS.3pm.gz
%{_mandir}/man3/RDF::Redland::Serializer.3pm.gz
%{_mandir}/man3/RDF::Redland::Statement.3pm.gz
%{_mandir}/man3/RDF::Redland::Storage.3pm.gz
%{_mandir}/man3/RDF::Redland::Stream.3pm.gz
%{_mandir}/man3/RDF::Redland::URI.3pm.gz
%{_mandir}/man3/RDF::Redland::URINode.3pm.gz
%{_mandir}/man3/RDF::Redland::XMLLiteralNode.3pm.gz
%endif

%package -n python-redland
Summary:        Python bindings for programs that use Redland
Group:          Development/Languages/Python
%requires_eq libredland0
Requires:       python-base = %{py_ver}

%description -n python-redland
Redland librdf Language bindings provide high-level interfaces for
RDF (Resource Description Framework) implemented on top of the
Redland librdf library which provides an object-based RDF API,
supports for syntaxes and triple stores.
Python language bindings for the Redland RDF library.

%files -n python-redland
%defattr(-, root, root)
%{python_sitearch}/RDF.py
%{python_sitearch}/Redland.py
%{python_sitearch}/_Redland.so

%define phpversion %(php-config --version)

%package -n php5-redland
Summary:        Php5 bindings for programs that use Redland
Group:          Development/Languages/Other
%requires_eq libredland0
Requires:       php5 => %{phpversion}

%description -n php5-redland
Redland librdf Language bindings provide high-level interfaces for
RDF (Resource Description Framework) implemented on top of the
Redland librdf library which provides an object-based RDF API,
supports for syntaxes and triple stores.
Php5 language bindings for the Redland RDF library.

%files -n php5-redland
%defattr(-, root, root)
%{_libdir}/php5/extensions/redland.so

%package -n ruby-redland
Summary:        Ruby bindings for programs that use Redland
Group:          Development/Languages/Ruby
%requires_eq libredland0

%description -n ruby-redland
Redland librdf Language bindings provide high-level interfaces for
RDF (Resource Description Framework) implemented on top of the
Redland librdf library which provides an object-based RDF API,
supports for syntaxes and triple stores.
Ruby language bindings for the Redland RDF library.

%files -n ruby-redland
%defattr(-, root, root)
%if 0%{?suse_version} >= 1220
%{rb_vendorarchdir}/redland.so
%{rb_vendorarchdir}/rdf
%else
%dir %{rb_libdir}/rdf
%dir %{rb_libdir}/rdf/redland
%dir %{rb_libdir}/rdf/redland/schemas
%{rb_libdir}/rdf/redland.rb
%{rb_libdir}/rdf/redland/*.rb
%{rb_libdir}/rdf/redland/schemas/foaf.rb
%{rb_libdir}/rdf/redland/schemas/owl.rb
%{rb_libdir}/rdf/redland/schemas/rdfs.rb
%{rb_archdir}/redland.so
%endif

%changelog
* Sat May 16 2015 tittiatcoke@gmail.com
- Drop the %%check section from the spec-file.
* Sun Mar 15 2015 p.drouand@gmail.com
- Update to version 1.0.17.1
  * Synchronise with [1]Redland 1.0.17 ([2]release notes).
  * Multiple Python bindings improvements (Python 3)
  * Fixed building with Ruby 2
  * Several other fixes and improvements including fixing reported issues:
  * [3]0000406, [4]0000549, [5]0000552 and [6]0000569.
* Thu Jan 24 2013 mlin@suse.com
- Update to version 1.0.16.1
  * Synchronise with Redland 1.0.16
  * Multiple Ruby bindings fixes for Ruby 1.9
  * SWIG 2.0.0 or newer required from next release. Not tested with
    SWIG 1.x
  * A few other minor fixes
  * Fixed Issues
  * 0000243: Ruby bindings emit lots of warnings when loading library
  * 0000444: Ruby bindings installation is incomplete (redland.bundle
    missing)
  * 0000480: installation for ruby could still be improved
  * 0000498: 'parse_string_into_model' calls 'parse_string_as_stream'
    with an incorrect number of parameters in Ruby binding
- Removed ruby-1.9.patch
* Mon Jun 18 2012 coolo@suse.com
- fix build with ruby 1.9 (partly from fedora)
* Wed Dec 21 2011 tittiatcoke@gmail.com
- Update to 1.0.14.1
  * Synchronise with Redland 1.0.14 (release notes).
  * Requires Redland 1.0.14, Rasqal 0.9.25 and Raptor 2.0.0 or
    newer.
  * SWIG 2.0.0 or newer is now recommended. Not tested with SWIG 1.x
  * Perl unicode fixes
  * PHP logging and error handling enhancements
  * Python fixes to allow subclassing
  * Fixed Issues: 0000473.
* Mon Sep 26 2011 coolo@suse.com
- fix requires
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 1.0.13
* Tue Feb 15 2011 davejplater@gmail.com
- Removed incomplete patch redland-perl-vendor_perl.patch until the
  fix is ready.
* Sun Jan 30 2011 davejplater@gmail.com
- Perl bindings install in site_arch disabled with bcond
* Sun Jan 16 2011 davejplater@gmail.com
- Added perl, python, php5 and ruby bindings.
* Tue Oct 19 2010 dmueller@suse.de
- update to 1.0.12:
  Enable librdf.h to be used as the top-level header in addition to
  redland.h
  Fix linking issues when building with GNU ld with DT_NEEDED disabled
  Fixed Issues: [1]#0000329, [2]#0000348 [3]#0000391, [4]#0000392 and
  [5]#0000393.
  Virtuoso storage backend querying now fully works.
  Several new convenience APIs were added and others deprecated.
  Support building with Raptor V2 API if configured with --with-raptor2.
  Exports more functions to SWIG language bindings.
  Switched to GIT version control [7]hosted by GitHub.
  Many other bug fixes and improvements were made.
  Fixed Issues: [8]#0000124, [9]#0000284, [10]#0000321, [11]#0000322,
  [12]#0000334, [13]#0000338, [14]#0000341, [15]#0000344, [16]#0000350,
  [17]#0000363, [18]#0000366, [19]#0000371, [20]#0000380, [21]#0000382
  and [22]#0000383
* Sat Jan  2 2010 dmueller@suse.de
- update to 1.0.10:
  Added a Virtuoso storage by Patrick van Kleef
  Support Rasqal 0.9.17 API
  Fix compiling against sqlite 3.6.17 or newer
  Fix modular storage dynamic loading linking problems
* Wed Dec 16 2009 dmueller@suse.de
- fix build
* Mon Jul 27 2009 beineri@opensuse.org
- update to version 1.0.9: many bug fixes
* Tue Jan 13 2009 coolo@suse.de
- fix the syntax of enums
* Thu Jul 24 2008 dmueller@suse.de
- update to 1.0.8
  * add in memory index trees
  * fix mysql connect hang
* Mon Apr  7 2008 dmueller@suse.de
- disable testsuite for older distributions
- build parallel again
* Sun Apr  6 2008 crrodriguez@suse.de
- update to version 1.0.7
  * 0000187: "rdf_query_results.c", line 630: void function cannot return value
  * 0000189: librdf_uri_is_file_uri: wrong return value
  * 0000203: API declarations for Symbian portability
  * 0000205: Memory leak in rdf_query_rasqal.c
  * 0000209: Null dereference + assertion failures in minimal librdf setup-cleanup
  * 0000213: Multiple instances of world object make trouble
  * 0000215: librdf_new_node_from_typed_counted_literal() does not respect parameter lengths
  * 0000218: librdf_query_execute does not assert model parameter
  * 0000229: Segmentation fault when invoking librdf_new_model_from_model()
  * 0000230: on Gentoo/FreeBSD redland fails compilation due to a missing #define pthread.h
  * 0000234: autogen.sh $dir quoting
  * 0000235: $(EXEEXT) in tests
  * 0000236: EOL issues when building svn version on cygwin
- disable static libraries
- remove "la" file
- cleanup -devel package dependencies again
* Thu Feb 28 2008 dmueller@suse.de
- add missing post/postun ldconfig calls
* Fri Feb 15 2008 dmueller@suse.de
- reduce -devel requires
* Tue Jan 15 2008 dmueller@suse.de
- build without postgres/mysql support for now, sqlite and bdb is
  enough. Please report if the backend support is required
* Wed May  9 2007 wstephenson@suse.de
- update to version 1.0.6
  * Added a new transactions API for graph changes, implemented for
    MySQL
  * Added a new query results formatter class
  * Many other bug fixes addressing Issues #0000175, #0000173,
    [#0000159], #0000153, #0000150 and #0000038
* Fri May  4 2007 dmueller@suse.de
- fix requires
* Thu May  3 2007 wstephenson@suse.de
- rename -devel subpackage
* Wed May  2 2007 wstephenson@suse.de
- update to version 1.0.5
  * Several API additions
  * Parsing methods can take a NULL base URI when it is not needed
  * Added serializer methods to serialize from a stream
  * Many fixes and improvements to the SQLite storage
  * Export some more functions to the SWIG binding
  * Many minor improvements
  * Many other bug fixes addressing Issues #0000092, #0000103,
    [#0000105], #0000107, #0000114, #0000116, #0000125, #0000130,
    [#0000132], #0000136 and #0000139.
* Thu Jul 13 2006 mrueckert@suse.de
- specfile cleanup
* Mon Jun 26 2006 dmacvicar@suse.de
- initial package of 1.0.4
